.. OPF ETL documentation master file, created by
   sphinx-quickstart on Tue Dec 29 08:23:20 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to OPF ETL's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 3

   intro
   install
   tutorial
   src/ooetl

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

